@@ -116,7 +116,7 @@ int main(int argc, char *argv[]) {
 		argv[1] = n;
 	}
 	parse_args(argc, argv);	/* sets many globals, opens a file */
-	set_cron_cwd();
+	check_spool_dir();
 	if (!allowed(RealUser, CRON_ALLOW, CRON_DENY)) {
 		fprintf(stderr,
 			"You (%s) are not allowed to use this program (%s)\n",
@@ -304,10 +304,6 @@ static void parse_args(int argc, char *argv[]) {
 	}
 
 	if (Option == opt_replace) {
-		/* we have to open the file here because we're going to
-		 * chdir(2) into /var/cron before we get around to
-		 * reading the file.
-		 */
 		if (!strcmp(Filename, "-"))
 			NewCrontab = stdin;
 		else {
@@ -462,7 +458,7 @@ static void edit_cmd(void) {
 	(void) signal(SIGQUIT, SIG_IGN);
 
 	if (!glue_strings(Filename, sizeof Filename, tmp_path(),
-			"crontab.XXXXXXXXXX", '/')) {
+			"crontab.XXXXXX", '/')) {
 		fprintf(stderr, "path too long\n");
 		exit(ERROR_EXIT);
 	}
@@ -699,13 +695,9 @@ static int replace_cmd(void) {
 	int error = 0;
 	entry *e;
 	uid_t file_owner;
-	char **envp = env_init();
+	char **envp;
 	char *safename;
 
-	if (envp == NULL) {
-		fprintf(stderr, "%s: Cannot allocate memory.\n", ProgramName);
-		return (-2);
-	}
 
 	safename = host_specific_filename("tmp.XXXXXXXXXX", 1);
 	if (!safename || !glue_strings(TempFilename, sizeof TempFilename, SPOOL_DIR,
@@ -774,6 +766,15 @@ static int replace_cmd(void) {
 	Set_LineNum(1 - NHEADER_LINES)
 		CheckErrorCount = 0;
 	eof = FALSE;
+
+	envp = env_init();
+	if (envp == NULL) {
+		fprintf(stderr, "%s: Cannot allocate memory.\n", ProgramName);
+		fclose(tmp);
+		error = -2;
+		goto done;
+	}
+
 	while (!CheckErrorCount && !eof) {
 		switch (load_env(envstr, tmp)) {
 		case ERR:
@@ -787,12 +788,13 @@ static int replace_cmd(void) {
 		case FALSE:
 			e = load_entry(tmp, check_error, pw, envp);
 			if (e)
-				free(e);
+				free_entry(e);
 			break;
 		case TRUE:
 			break;
 		}
 	}
+	env_free(envp);
 
 	if (CheckErrorCount != 0) {
 		fprintf(stderr, "errors in crontab file, can't install.\n");
