@@ -222,11 +222,11 @@ void set_cron_uid(void) {
 #endif
 }
 
-void set_cron_cwd(void) {
+void check_spool_dir(void) {
 	struct stat sb;
+#ifdef CRON_GROUP
 	struct group *grp = NULL;
 
-#ifdef CRON_GROUP
 	grp = getgrnam(CRON_GROUP);
 #endif
 	/* check SPOOL_DIR existence
@@ -235,7 +235,10 @@ void set_cron_cwd(void) {
 		perror(SPOOL_DIR);
 		if (OK == mkdir(SPOOL_DIR, 0700)) {
 			fprintf(stderr, "%s: created\n", SPOOL_DIR);
-			stat(SPOOL_DIR, &sb);
+			if (stat(SPOOL_DIR, &sb) < OK) {
+				perror("stat retry");
+				exit(ERROR_EXIT);
+			}
 		}
 		else {
 			fprintf(stderr, "%s: ", SPOOL_DIR);
@@ -247,10 +250,11 @@ void set_cron_cwd(void) {
 		fprintf(stderr, "'%s' is not a directory, bailing out.\n", SPOOL_DIR);
 		exit(ERROR_EXIT);
 	}
+#ifdef CRON_GROUP
 	if (grp != NULL) {
 		if (sb.st_gid != grp->gr_gid)
 			if (chown(SPOOL_DIR, -1, grp->gr_gid) == -1) {
-				fprintf(stderr, "chdir %s failed: %s\n", SPOOL_DIR,
+				fprintf(stderr, "chown %s failed: %s\n", SPOOL_DIR,
 					strerror(errno));
 				exit(ERROR_EXIT);
 			}
@@ -261,6 +265,7 @@ void set_cron_cwd(void) {
 				exit(ERROR_EXIT);
 			}
 	}
+#endif
 }
 
 /* acquire_daemonlock() - write our PID into /etc/cron.pid, unless
