@@ -41,15 +41,14 @@ static int
 cron_conv(int num_msg, const struct pam_message **msgm,
         struct pam_response **response, void *appdata_ptr)
 {
-        struct pam_message**m = msgm;
         int i;
 
         for (i = 0; i < num_msg; i++) {
-                switch (m[i]->msg_style) {
+                switch (msgm[i]->msg_style) {
                         case PAM_ERROR_MSG:
                         case PAM_TEXT_INFO:
-                                if (m[i]->msg != NULL) {
-                                        log_it("CRON", getpid(), "pam_message", m[i]->msg, 0);
+                                if (msgm[i]->msg != NULL) {
+                                        log_it("CRON", getpid(), "pam_message", msgm[i]->msg, 0);
                                 }
                         break;
                         default:
@@ -66,7 +65,7 @@ static const struct pam_conv conv = {
 static int cron_open_pam_session(struct passwd *pw);
 
 # define PAM_FAIL_CHECK if (retcode != PAM_SUCCESS) { \
-	fprintf(stderr,"\n%s\n",pam_strerror(pamh, retcode)); \
+	log_it(pw->pw_name, getpid(), "PAM ERROR", pam_strerror(pamh, retcode), 0); \
 	if (pamh != NULL) { \
 		if (pam_session_opened != 0) \
 			pam_close_session(pamh, PAM_SILENT); \
@@ -143,13 +142,10 @@ int cron_set_job_security_context(entry * e, user * u, char ***jobenv) {
 	}
 #endif
 
-	if (cron_change_user(e->pwd) != 0) {
-		log_it(e->pwd->pw_name, getpid(), "ERROR", "failed to change user", 0);
+	if (cron_change_groups(e->pwd) != 0) {
 		return -1;
 	}
 
-	log_close();
-
 	time_t job_run_time = time(0L);
 
 	if ((minutely_time > 0) && ((job_run_time / 60) != (minutely_time / 60))) {
@@ -212,11 +208,9 @@ void cron_close_pam(void) {
 #endif
 }
 
-int cron_change_user(struct passwd *pw) {
+int cron_change_groups(struct passwd *pw) {
 	pid_t pid = getpid();
-	/* set our directory, uid and gid.  Set gid first, since once
-	 * we set uid, we've lost root privledges.
-	 */
+
 	if (setgid(pw->pw_gid) != 0) {
 		log_it("CRON", pid, "ERROR", "setgid failed", errno);
 		return -1;
@@ -227,10 +221,11 @@ int cron_change_user(struct passwd *pw) {
 		return -1;
 	}
 
-	if (setreuid(pw->pw_uid, -1) != 0) {
-		log_it("CRON", pid, "ERROR", "setreuid failed", errno);
-		return -1;
-	}
+#if defined(WITH_PAM)
+	/* credentials may take form of supplementary groups so reinitialize
+	 * them here */
+	pam_setcred(pamh, PAM_REINITIALIZE_CRED | PAM_SILENT);
+#endif
 
 	return 0;
 }
@@ -240,11 +235,14 @@ int cron_change_user_permanently(struct passwd *pw, char *homedir) {
 		log_it("CRON", getpid(), "ERROR", "setreuid failed", errno);
 		return -1;
 	}
+
 	if (chdir(homedir) == -1) {
 		log_it("CRON", getpid(), "ERROR chdir failed", homedir, errno);
 		return -1;
 	}
 
+	log_close();
+
 	return 0;
 }
 
@@ -254,7 +252,19 @@ static int cron_authorize_context(security_context_t scontext,
 #ifdef WITH_SELINUX
 	struct av_decision avd;
 	int retval;
-	unsigned int bit = FILE__ENTRYPOINT;
+	security_class_t tclass;
+	access_vector_t bit;
+
+	tclass = string_to_security_class("file");
+	if (!tclass) {
+		log_it("CRON", getpid(), "ERROR", "Failed to translate security class file", errno);
+		return 0;
+	}
+	bit = string_to_av_perm(tclass, "entrypoint");
+	if (!bit) {
+		log_it("CRON", getpid(), "ERROR", "Failed to translate av perm entrypoint", errno);
+		return 0;
+	}
 	/*
 	 * Since crontab files are not directly executed,
 	 * crond must ensure that the crontab file has
@@ -263,7 +273,7 @@ static int cron_authorize_context(security_context_t scontext,
 	 * permission check for this purpose.
 	 */
 	retval = security_compute_av(scontext, file_context,
-		SECCLASS_FILE, bit, &avd);
+		tclass, bit, &avd);
 	if (retval || ((bit & avd.allowed) != bit))
 		return 0;
 #endif
@@ -275,14 +285,27 @@ static int cron_authorize_range(security_context_t scontext,
 #ifdef WITH_SELINUX
 	struct av_decision avd;
 	int retval;
-	unsigned int bit = CONTEXT__CONTAINS;
+	security_class_t tclass;
+	access_vector_t bit;
+
+	tclass = string_to_security_class("context");
+	if (!tclass) {
+		log_it("CRON", getpid(), "ERROR", "Failed to translate security class context", errno);
+		return 0;
+	}
+	bit = string_to_av_perm(tclass, "contains");
+	if (!bit) {
+		log_it("CRON", getpid(), "ERROR", "Failed to translate av perm contains", errno);
+		return 0;
+	}
+
 	/*
 	 * Since crontab files are not directly executed,
 	 * so crond must ensure that any user specified range
 	 * falls within the seusers-specified range for that Linux user.
 	 */
 	retval = security_compute_av(scontext, ucontext,
-		SECCLASS_CONTEXT, bit, &avd);
+		tclass, bit, &avd);
 
 	if (retval || ((bit & avd.allowed) != bit))
 		return 0;
@@ -309,18 +332,21 @@ cron_get_job_range(user * u, security_context_t * ucontextp, char **jobenv) {
 		if (!(ccon = context_new(u->scontext))) {
 			log_it(u->name, getpid(), "context_new FAILED for MLS_LEVEL",
 				range, 0);
+			context_free(ccon);
 			return -1;
 		}
 
 		if (context_range_set(ccon, range)) {
 			log_it(u->name, getpid(),
 				"context_range_set FAILED for MLS_LEVEL", range, 0);
+			context_free(ccon);
 			return -1;
 		}
 
 		if (!(*ucontextp = context_str(ccon))) {
 			log_it(u->name, getpid(), "context_str FAILED for MLS_LEVEL",
 				range, 0);
+			context_free(ccon);
 			return -1;
 		}
 
@@ -479,15 +505,22 @@ get_security_context(const char *name, int crontab_fd,
 	}
 
 	if (!cron_authorize_context(scontext, file_context)) {
+		char *msg=NULL;
+		if (asprintf(&msg,
+		     "Unauthorized SELinux context=%s file_context=%s", (char *) scontext, file_context) >= 0) {
+			log_it(name, getpid(), msg, tabname, 0);
+			free(msg);
+		} else {
+			log_it(name, getpid(), "Unauthorized SELinux context", tabname, 0);
+		}
 		freecon(scontext);
 		freecon(file_context);
 		if (security_getenforce() > 0) {
-			log_it(name, getpid(), "Unauthorized SELinux context", tabname, 0);
 			return -1;
 		}
 		else {
 			log_it(name, getpid(),
-				"Unauthorized SELinux context, but SELinux in permissive mode, continuing",
+				"SELinux in permissive mode, continuing",
 				tabname, 0);
 			return 0;
 		}
@@ -515,22 +548,30 @@ int crontab_security_access(void) {
 		security_context_t user_context;
 		if (getprevcon_raw(&user_context) == 0) {
 			security_class_t passwd_class;
+			access_vector_t crontab_bit;
 			struct av_decision avd;
-			int retval;
+			int retval = 0;
 
 			passwd_class = string_to_security_class("passwd");
 			if (passwd_class == 0) {
-				selinux_check_passwd_access = -1;
 				fprintf(stderr, "Security class \"passwd\" is not defined in the SELinux policy.\n");
+				retval = -1;
 			}
 
-			retval = security_compute_av_raw(user_context,
-							user_context,
-							passwd_class,
-							PASSWD__CRONTAB,
-							&avd);
+			if (retval == 0) {
+				crontab_bit = string_to_av_perm(passwd_class, "crontab");
+				if (crontab_bit == 0) {
+					fprintf(stderr, "Security av permission \"crontab\" is not defined in the SELinux policy.\n");
+					retval = -1;
+				}
+			}
 
-			if ((retval == 0) && ((PASSWD__CRONTAB & avd.allowed) == PASSWD__CRONTAB)) {
+			if (retval == 0)
+				retval = security_compute_av_raw(user_context,
+					user_context, passwd_class,
+					crontab_bit, &avd);
+
+			if ((retval == 0) && ((crontab_bit & avd.allowed) == crontab_bit)) {
 				selinux_check_passwd_access = 0;
 			}
 			freecon(user_context);
